Crate tsync

Crate tsync 

Modules

utils

Structs

BuildSettings
Settings for the build process
BuildState

Functions

generate_typescript_defs
generate_typescript_defs_inner

Attribute Macros

tsync
the #tsync attribute macro which marks structs and types to be translated into the final typescript definitions file